package at.ac.uibk.gitsearch.config;

import java.util.List;

import org.springframework.boot.context.properties.ConfigurationProperties;

/**
 * Properties specific to Gitsearch.
 * <p>
 * Properties are configured in the {@code application.yml} file.
 * See {@link io.github.jhipster.config.JHipsterProperties} for a good example.
 */
@ConfigurationProperties(prefix = "application", ignoreUnknownFields = false)
public class ApplicationProperties {

    private Search search;

    private GitLab gitLab;
    
    private DeploymentInfo deploymentInfo;
    
    private List<String>  registeredPlugins;

    /**
     * a list of URLs of plugins to be registered.
	 * @return the registeredPlugins
	 */
	public List<String> getRegisteredPlugins() {
		return registeredPlugins;
	}

	/**
	 * @param registeredPlugins the registeredPlugins to set
	 */
	public void setRegisteredPlugins(List<String>  registeredPlugins) {
		this.registeredPlugins = registeredPlugins;
	}

	public Search getSearch() {
        return search;
    }

    public void setSearch(Search search) {
        this.search = search;
    }

    public GitLab getGitLab() {
        return gitLab;
    }

    public void setGitLab(GitLab gitLab) {
        this.gitLab = gitLab;
    }

    /**
	 * @return the deploymentInfo
	 */
	public DeploymentInfo getDeploymentInfo() {
		return deploymentInfo;
	}

	/**
	 * @param deploymentInfo the deploymentInfo to set
	 */
	public void setDeploymentInfo(DeploymentInfo deploymentInfo) {
		this.deploymentInfo = deploymentInfo;
	}

	public static class Search {

        private String highlightPre;
        private String highlightPost;

        public String getHighlightPre() {
            return highlightPre;
        }

        public void setHighlightPre(String highlightPre) {
            this.highlightPre = highlightPre;
        }

        public String getHighlightPost() {
            return highlightPost;
        }

        public void setHighlightPost(String highlightPost) {
            this.highlightPost = highlightPost;
        }
    }

    public static class GitLab {
        private String url;
        private String mainGroup;
        private String generalAccessToken;
        
        public String getUrl() {
            return url;
        }

        public void setUrl(String url) {
            this.url = url;
        }

        public String getMainGroup() {
            return mainGroup;
        }

        public void setMainGroup(String mainGroup) {
            this.mainGroup = mainGroup;
        }

		/**
		 * @return the generalAccessToken
		 */
		public String getGeneralAccessToken() {
			return generalAccessToken;
		}

		/**
		 * @param generalAccessToken the generalAccessToken to set
		 */
		public void setGeneralAccessToken(String generalAccessToken) {
			this.generalAccessToken = generalAccessToken;
		}
        
    }
    
    public static class DeploymentInfo {
    	private String commitId;
    	private String branch;
		/**
		 * @return the commitId
		 */
		public String getCommitId() {
			return commitId;
		}
		/**
		 * @param commitId the commitId to set
		 */
		public void setCommitId(String commitId) {
			this.commitId = commitId;
		}
		/**
		 * @return the branch
		 */
		public String getBranch() {
			return branch;
		}
		/**
		 * @param branch the branch to set
		 */
		public void setBranch(String branch) {
			this.branch = branch;
		}
    }
}
